@@ -46,35 +46,36 @@ stop_workers (struct MHD_Daemon *daemon)
     fd = daemon->listen_socket;
   /* Let workers shutdown in parallel. */
   for (i = 0; i < daemon->worker_pool_size; i++)
+  {
+    daemon->worker_pool[i].shutdown = true;
+    if (MHD_ITC_IS_VALID_ (daemon->worker_pool[i].itc))
     {
-      daemon->worker_pool[i].shutdown = true;
-      if (MHD_ITC_IS_VALID_(daemon->worker_pool[i].itc))
-	{
-	  if (! MHD_itc_activate_ (daemon->worker_pool[i].itc,
-				   "e"))
-	    MHD_PANIC (_("Failed to signal shutdown via inter-thread communication channel."));
-	}
-      else
-	{
-	  /* Better hope shutdown() works... */
-	  mhd_assert (MHD_INVALID_SOCKET != fd);
-	}
+      if (! MHD_itc_activate_ (daemon->worker_pool[i].itc,
+                               "e"))
+        MHD_PANIC (_ (
+                     "Failed to signal shutdown via inter-thread communication channel."));
     }
+    else
+    {
+      /* Better hope shutdown() works... */
+      mhd_assert (MHD_INVALID_SOCKET != fd);
+    }
+  }
 #ifdef HAVE_LISTEN_SHUTDOWN
   if (MHD_INVALID_SOCKET != fd)
-    {
-      (void) shutdown (fd,
-		       SHUT_RDWR);
-    }
+  {
+    (void) shutdown (fd,
+                     SHUT_RDWR);
+  }
 #endif /* HAVE_LISTEN_SHUTDOWN */
   for (i = 0; i < daemon->worker_pool_size; ++i)
-    {
-      MHD_daemon_destroy (&daemon->worker_pool[i]);
-    }
+  {
+    MHD_daemon_destroy (&daemon->worker_pool[i]);
+  }
   free (daemon->worker_pool);
   daemon->worker_pool = NULL;
   /* FIXME: does this still hold? */
-  mhd_assert (MHD_ITC_IS_INVALID_(daemon->itc));
+  mhd_assert (MHD_ITC_IS_INVALID_ (daemon->itc));
 #ifdef EPOLL_SUPPORT
   mhd_assert (-1 == daemon->epoll_fd);
 #if defined(HTTPS_SUPPORT) && defined(UPGRADE_SUPPORT)
@@ -104,65 +105,66 @@ MHD_daemon_destroy (struct MHD_Daemon *daemon)
   /* FIXME: convert from here to microhttpd2-style API! */
 
   if (NULL != daemon->worker_pool)
-    { /* Master daemon with worker pool. */
-      stop_workers (daemon);
-    }
+  {   /* Master daemon with worker pool. */
+    stop_workers (daemon);
+  }
   else
+  {
+    mhd_assert (0 == daemon->worker_pool_size);
+    /* Worker daemon or single-thread daemon. */
+    if (MHD_TM_EXTERNAL_EVENT_LOOP != daemon->threading_mode)
     {
-      mhd_assert (0 == daemon->worker_pool_size);
-      /* Worker daemon or single-thread daemon. */
-      if (MHD_TM_EXTERNAL_EVENT_LOOP != daemon->threading_mode)
-        {
-	  /* Worker daemon or single daemon with internal thread(s). */
-	  /* Separate thread(s) is used for polling sockets. */
-	  if (MHD_ITC_IS_VALID_(daemon->itc))
-	    {
-	      if (! MHD_itc_activate_ (daemon->itc,
-				       "e"))
-		MHD_PANIC (_("Failed to signal shutdown via inter-thread communication channel"));
-	    }
-	  else
-	    {
-#ifdef HAVE_LISTEN_SHUTDOWN
-	      if (MHD_INVALID_SOCKET != fd)
-		{
-		  if (NULL == daemon->master)
-		    (void) shutdown (fd,
-				     SHUT_RDWR);
-		}
-	      else
-#endif /* HAVE_LISTEN_SHUTDOWN */
-		mhd_assert (false); /* Should never happen */
-	    }
-
-	  if (! MHD_join_thread_ (daemon->pid.handle))
-	    {
-	      MHD_PANIC (_("Failed to join a thread\n"));
-	    }
-	  /* close_all_connections() was called in daemon thread. */
-	}
-      else
-        {
-          /* No internal threads are used for polling sockets
-	     (external event loop) */
-          MHD_daemon_close_all_connections_ (daemon);
-        }
+      /* Worker daemon or single daemon with internal thread(s). */
+      /* Separate thread(s) is used for polling sockets. */
       if (MHD_ITC_IS_VALID_ (daemon->itc))
-        MHD_itc_destroy_chk_ (daemon->itc);
+      {
+        if (! MHD_itc_activate_ (daemon->itc,
+                                 "e"))
+          MHD_PANIC (_ (
+                       "Failed to signal shutdown via inter-thread communication channel"));
+      }
+      else
+      {
+#ifdef HAVE_LISTEN_SHUTDOWN
+        if (MHD_INVALID_SOCKET != fd)
+        {
+          if (NULL == daemon->master)
+            (void) shutdown (fd,
+                             SHUT_RDWR);
+        }
+        else
+#endif /* HAVE_LISTEN_SHUTDOWN */
+        mhd_assert (false); /* Should never happen */
+      }
+
+      if (! MHD_join_thread_ (daemon->pid.handle))
+      {
+        MHD_PANIC (_ ("Failed to join a thread\n"));
+      }
+      /* close_all_connections() was called in daemon thread. */
+    }
+    else
+    {
+      /* No internal threads are used for polling sockets
+   (external event loop) */
+      MHD_daemon_close_all_connections_ (daemon);
+    }
+    if (MHD_ITC_IS_VALID_ (daemon->itc))
+      MHD_itc_destroy_chk_ (daemon->itc);
 
 #ifdef EPOLL_SUPPORT
-      if ( (MHD_ELS_EPOLL == daemon->event_loop_syscall) &&
-           (-1 != daemon->epoll_fd) )
-        MHD_socket_close_chk_ (daemon->epoll_fd);
+    if ( (MHD_ELS_EPOLL == daemon->event_loop_syscall) &&
+         (-1 != daemon->epoll_fd) )
+      MHD_socket_close_chk_ (daemon->epoll_fd);
 #if defined(HTTPS_SUPPORT) && defined(UPGRADE_SUPPORT)
-      if ( (MHD_ELS_EPOLL == daemon->event_loop_syscall) &&
-           (-1 != daemon->epoll_upgrade_fd) )
-        MHD_socket_close_chk_ (daemon->epoll_upgrade_fd);
+    if ( (MHD_ELS_EPOLL == daemon->event_loop_syscall) &&
+         (-1 != daemon->epoll_upgrade_fd) )
+      MHD_socket_close_chk_ (daemon->epoll_upgrade_fd);
 #endif /* HTTPS_SUPPORT && UPGRADE_SUPPORT */
 #endif /* EPOLL_SUPPORT */
 
-      MHD_mutex_destroy_chk_ (&daemon->cleanup_connection_mutex);
-    }
+    MHD_mutex_destroy_chk_ (&daemon->cleanup_connection_mutex);
+  }
 
   if (NULL != daemon->master)
     return;
@@ -175,18 +177,18 @@ MHD_daemon_destroy (struct MHD_Daemon *daemon)
   /* TLS clean up */
 #ifdef HTTPS_SUPPORT
   if (NULL != daemon->tls_api)
-    {
+  {
 #if FIXME_TLS_API
-      if (daemon->have_dhparams)
-	{
-	  gnutls_dh_params_deinit (daemon->https_mem_dhparams);
-	  daemon->have_dhparams = false;
-	}
-      gnutls_priority_deinit (daemon->priority_cache);
-      if (daemon->x509_cred)
-	gnutls_certificate_free_credentials (daemon->x509_cred);
-#endif
+    if (daemon->have_dhparams)
+    {
+      gnutls_dh_params_deinit (daemon->https_mem_dhparams);
+      daemon->have_dhparams = false;
     }
+    gnutls_priority_deinit (daemon->priority_cache);
+    if (daemon->x509_cred)
+      gnutls_certificate_free_credentials (daemon->x509_cred);
+#endif
+  }
 #endif /* HTTPS_SUPPORT */
 
 #ifdef DAUTH_SUPPORT
