@@ -59,22 +59,22 @@ recv_tls_adapter (struct MHD_Connection *connection,
                             i);
   if ( (GNUTLS_E_AGAIN == res) ||
        (GNUTLS_E_INTERRUPTED == res) )
-    {
+  {
 #ifdef EPOLL_SUPPORT
-      if (GNUTLS_E_AGAIN == res)
-        connection->epoll_state &= ~MHD_EPOLL_STATE_READ_READY;
+    if (GNUTLS_E_AGAIN == res)
+      connection->epoll_state &= ~MHD_EPOLL_STATE_READ_READY;
 #endif
-      /* Any network errors means that buffer is empty. */
-      connection->tls_read_ready = false;
-      return MHD_ERR_AGAIN_;
-    }
+    /* Any network errors means that buffer is empty. */
+    connection->tls_read_ready = false;
+    return MHD_ERR_AGAIN_;
+  }
   if (res < 0)
-    {
-      /* Likely 'GNUTLS_E_INVALID_SESSION' (client communication
-         disrupted); interpret as a hard error */
-      connection->tls_read_ready = false;
-      return MHD_ERR_NOTCONN_;
-    }
+  {
+    /* Likely 'GNUTLS_E_INVALID_SESSION' (client communication
+       disrupted); interpret as a hard error */
+    connection->tls_read_ready = false;
+    return MHD_ERR_NOTCONN_;
+  }
 
 #ifdef EPOLL_SUPPORT
   /* Unlike non-TLS connections, do not reset "read-ready" if
@@ -83,8 +83,9 @@ recv_tls_adapter (struct MHD_Connection *connection,
 #endif /* EPOLL_SUPPORT */
 
   /* Check whether TLS buffers still have some unread data. */
-  connection->tls_read_ready = ( ((size_t)res == i) &&
-                                 (0 != gnutls_record_check_pending (connection->tls_session)) );
+  connection->tls_read_ready = ( ((size_t) res == i) &&
+                                 (0 != gnutls_record_check_pending (
+                                    connection->tls_session)) );
   return res;
 }
 
@@ -98,7 +99,7 @@ recv_tls_adapter (struct MHD_Connection *connection,
  * @return positive value for number of bytes actually sent or
  *         negative value for error number MHD_ERR_xxx_
  */
-static ssize_t
+ssize_t
 send_tls_adapter (struct MHD_Connection *connection,
                   const void *other,
                   size_t i)
@@ -113,19 +114,19 @@ send_tls_adapter (struct MHD_Connection *connection,
                             i);
   if ( (GNUTLS_E_AGAIN == res) ||
        (GNUTLS_E_INTERRUPTED == res) )
-    {
+  {
 #ifdef EPOLL_SUPPORT
-      if (GNUTLS_E_AGAIN == res)
-        connection->epoll_state &= ~MHD_EPOLL_STATE_WRITE_READY;
+    if (GNUTLS_E_AGAIN == res)
+      connection->epoll_state &= ~MHD_EPOLL_STATE_WRITE_READY;
 #endif
-      return MHD_ERR_AGAIN_;
-    }
+    return MHD_ERR_AGAIN_;
+  }
   if (res < 0)
-    {
-      /* Likely 'GNUTLS_E_INVALID_SESSION' (client communication
-         disrupted); interpret as a hard error */
-      return MHD_ERR_NOTCONN_;
-    }
+  {
+    /* Likely 'GNUTLS_E_INVALID_SESSION' (client communication
+       disrupted); interpret as a hard error */
+    return MHD_ERR_NOTCONN_;
+  }
 #ifdef EPOLL_SUPPORT
   /* Unlike non-TLS connections, do not reset "write-ready" if
    * sent amount smaller than provided amount, as TLS
@@ -151,32 +152,32 @@ MHD_run_tls_handshake_ (struct MHD_Connection *connection)
 
   if ((MHD_TLS_CONN_INIT == connection->tls_state) ||
       (MHD_TLS_CONN_HANDSHAKING == connection->tls_state))
+  {
+    ret = gnutls_handshake (connection->tls_session);
+    if (ret == GNUTLS_E_SUCCESS)
     {
-      ret = gnutls_handshake (connection->tls_session);
-      if (ret == GNUTLS_E_SUCCESS)
-	{
-	  /* set connection TLS state to enable HTTP processing */
-	  connection->tls_state = MHD_TLS_CONN_CONNECTED;
-	  MHD_update_last_activity_ (connection);
-	  return true;
-	}
-      if ( (GNUTLS_E_AGAIN == ret) ||
-	   (GNUTLS_E_INTERRUPTED == ret) )
-	{
-          connection->tls_state = MHD_TLS_CONN_HANDSHAKING;
-	  /* handshake not done */
-	  return false;
-	}
-      /* handshake failed */
-      connection->tls_state = MHD_TLS_CONN_TLS_FAILED;
-#ifdef HAVE_MESSAGES
-      MHD_DLOG (connection->daemon,
-		_("Error: received handshake message out of context\n"));
-#endif
-      MHD_connection_close_ (connection,
-                             MHD_REQUEST_TERMINATED_WITH_ERROR);
+      /* set connection TLS state to enable HTTP processing */
+      connection->tls_state = MHD_TLS_CONN_CONNECTED;
+      MHD_update_last_activity_ (connection);
+      return true;
+    }
+    if ( (GNUTLS_E_AGAIN == ret) ||
+         (GNUTLS_E_INTERRUPTED == ret) )
+    {
+      connection->tls_state = MHD_TLS_CONN_HANDSHAKING;
+      /* handshake not done */
       return false;
     }
+    /* handshake failed */
+    connection->tls_state = MHD_TLS_CONN_TLS_FAILED;
+#ifdef HAVE_MESSAGES
+    MHD_DLOG (connection->daemon,
+              _ ("Error: received handshake message out of context\n"));
+#endif
+    MHD_connection_close_ (connection,
+                           MHD_REQUEST_TERMINATED_WITH_ERROR);
+    return false;
+  }
   return true;
 }
 
@@ -205,23 +206,23 @@ bool
 MHD_tls_connection_shutdown (struct MHD_Connection *connection)
 {
   if (MHD_TLS_CONN_WR_CLOSED > connection->tls_state)
+  {
+    const int res =
+      gnutls_bye (connection->tls_session, GNUTLS_SHUT_WR);
+    if (GNUTLS_E_SUCCESS == res)
     {
-      const int res =
-          gnutls_bye (connection->tls_session, GNUTLS_SHUT_WR);
-      if (GNUTLS_E_SUCCESS == res)
-        {
-          connection->tls_state = MHD_TLS_CONN_WR_CLOSED;
-          return true;
-        }
-      if ((GNUTLS_E_AGAIN == res) ||
-          (GNUTLS_E_INTERRUPTED == res))
-        {
-          connection->tls_state = MHD_TLS_CONN_WR_CLOSING;
-          return true;
-        }
-      else
-        connection->tls_state = MHD_TLS_CONN_TLS_FAILED;
+      connection->tls_state = MHD_TLS_CONN_WR_CLOSED;
+      return true;
     }
+    if ((GNUTLS_E_AGAIN == res) ||
+        (GNUTLS_E_INTERRUPTED == res))
+    {
+      connection->tls_state = MHD_TLS_CONN_WR_CLOSING;
+      return true;
+    }
+    else
+      connection->tls_state = MHD_TLS_CONN_TLS_FAILED;
+  }
   return false;
 }
 
