@@ -37,10 +37,10 @@
  * @param err the WinSock error code.
  * @return pointer to string description of specified WinSock error.
  */
-const char* MHD_W32_strerror_winsock_(int err)
+const char*MHD_W32_strerror_winsock_ (int err)
 {
   switch (err)
-    {
+  {
   case 0:
     return "No error";
   case WSA_INVALID_HANDLE:
@@ -233,7 +233,7 @@ const char* MHD_W32_strerror_winsock_(int err)
     return "Invalid QoS shaping rate object";
   case WSA_QOS_RESERVED_PETYPE:
     return "Reserved policy QoS element type";
-    }
+  }
   return "Unknown winsock error";
 }
 
@@ -246,113 +246,114 @@ const char* MHD_W32_strerror_winsock_(int err)
  * @return non-zero if succeeded, zero otherwise
  */
 int
-MHD_W32_socket_pair_(SOCKET sockets_pair[2], int non_blk)
+MHD_W32_socket_pair_ (SOCKET sockets_pair[2], int non_blk)
 {
   int i;
 
   if (! sockets_pair)
-    {
-      WSASetLastError (WSAEFAULT);
-      return 0;
-    }
+  {
+    WSASetLastError (WSAEFAULT);
+    return 0;
+  }
 
 #define PAIRMAXTRYIES 800
   for (i = 0; i < PAIRMAXTRYIES; i++)
+  {
+    struct sockaddr_in listen_addr;
+    SOCKET listen_s;
+    static const int c_addinlen = sizeof(struct sockaddr_in);   /* help compiler to optimize */
+    int addr_len = c_addinlen;
+    unsigned long on_val = 1;
+    unsigned long off_val = 0;
+
+    listen_s = socket (AF_INET,
+                       SOCK_STREAM,
+                       IPPROTO_TCP);
+    if (INVALID_SOCKET == listen_s)
+      break;   /* can't create even single socket */
+
+    listen_addr.sin_family = AF_INET;
+    listen_addr.sin_port = 0;   /* same as htons(0) */
+    listen_addr.sin_addr.s_addr = htonl (INADDR_LOOPBACK);
+    if ( ((0 == bind (listen_s,
+                      (struct sockaddr*) &listen_addr,
+                      c_addinlen)) &&
+          (0 == listen (listen_s,
+                        1) ) &&
+          (0 == getsockname (listen_s,
+                             (struct sockaddr*) &listen_addr,
+                             &addr_len))) )
     {
-      struct sockaddr_in listen_addr;
-      SOCKET listen_s;
-      static const int c_addinlen = sizeof(struct sockaddr_in); /* help compiler to optimize */
-      int addr_len = c_addinlen;
-      unsigned long on_val = 1;
-      unsigned long off_val = 0;
+      SOCKET client_s = socket (AF_INET,
+                                SOCK_STREAM,
+                                IPPROTO_TCP);
+      struct sockaddr_in accepted_from_addr;
+      struct sockaddr_in client_addr;
+      SOCKET server_s;
 
-      listen_s = socket (AF_INET,
-                         SOCK_STREAM,
-                         IPPROTO_TCP);
-      if (INVALID_SOCKET == listen_s)
-        break; /* can't create even single socket */
+      if (INVALID_SOCKET == client_s)
+      {
+        /* try again */
+        closesocket (listen_s);
+        continue;
+      }
 
-      listen_addr.sin_family = AF_INET;
-      listen_addr.sin_port = 0; /* same as htons(0) */
-      listen_addr.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
-      if ( (0 == bind (listen_s,
-                       (struct sockaddr*) &listen_addr,
-                       c_addinlen) &&
-            (0 == listen (listen_s,
-                          1) ) &&
-            (0 == getsockname (listen_s,
-                               (struct sockaddr*) &listen_addr,
-                               &addr_len))) )
-        {
-          SOCKET client_s = socket(AF_INET,
-                                   SOCK_STREAM,
-                                   IPPROTO_TCP);
-          struct sockaddr_in accepted_from_addr;
-          struct sockaddr_in client_addr;
-          SOCKET server_s;
+      if ( (0 != ioctlsocket (client_s,
+                              FIONBIO,
+                              &on_val)) ||
+           ( (0 != connect (client_s,
+                            (struct sockaddr*) &listen_addr,
+                            c_addinlen)) &&
+             (WSAGetLastError () != WSAEWOULDBLOCK)) )
+      {
+        /* try again */
+        closesocket (listen_s);
+        closesocket (client_s);
+        continue;
+      }
 
-          if (INVALID_SOCKET == client_s)
-            {
-              /* try again */
-              closesocket (listen_s);
-              continue;
-            }
+      addr_len = c_addinlen;
+      server_s = accept (listen_s,
+                         (struct sockaddr*) &accepted_from_addr,
+                         &addr_len);
+      if (INVALID_SOCKET == server_s)
+      {
+        /* try again */
+        closesocket (listen_s);
+        closesocket (client_s);
+        continue;
+      }
 
-          if ( (0 != ioctlsocket (client_s,
-                                  FIONBIO,
-                                  &on_val)) ||
-               ( (0 != connect (client_s,
-                                (struct sockaddr*) &listen_addr,
-                                c_addinlen)) &&
-                 (WSAGetLastError() != WSAEWOULDBLOCK)) )
-            {
-              /* try again */
-              closesocket (listen_s);
-              closesocket (client_s);
-              continue;
-            }
-
-          addr_len = c_addinlen;
-          server_s = accept (listen_s,
-                             (struct sockaddr*) &accepted_from_addr,
-                             &addr_len);
-          if (INVALID_SOCKET == server_s)
-            {
-              /* try again */
-              closesocket (listen_s);
-              closesocket (client_s);
-              continue;
-            }
-
-          addr_len = c_addinlen;
-          if ( (0 == getsockname (client_s,
-                                  (struct sockaddr*) &client_addr,
-                                  &addr_len)) &&
-               (accepted_from_addr.sin_family == client_addr.sin_family) &&
-               (accepted_from_addr.sin_port == client_addr.sin_port) &&
-               (accepted_from_addr.sin_addr.s_addr == client_addr.sin_addr.s_addr) &&
-               ( (0 != non_blk) ?
-                    (0 == ioctlsocket(server_s,
-                                      FIONBIO,
-                                      &on_val)) :
-                    (0 == ioctlsocket(client_s,
-                                      FIONBIO,
-                                      &off_val)) ) )
-            {
-              closesocket (listen_s);
-              sockets_pair[0] = server_s;
-              sockets_pair[1] = client_s;
-              return !0;
-            }
-          closesocket (server_s);
-          closesocket (client_s);
-        }
-      closesocket(listen_s);
+      addr_len = c_addinlen;
+      if ( (0 == getsockname (client_s,
+                              (struct sockaddr*) &client_addr,
+                              &addr_len)) &&
+           (accepted_from_addr.sin_family == client_addr.sin_family) &&
+           (accepted_from_addr.sin_port == client_addr.sin_port) &&
+           (accepted_from_addr.sin_addr.s_addr ==
+            client_addr.sin_addr.s_addr) &&
+           ( (0 != non_blk) ?
+             (0 == ioctlsocket (server_s,
+                                FIONBIO,
+                                &on_val)) :
+             (0 == ioctlsocket (client_s,
+                                FIONBIO,
+                                &off_val)) ) )
+      {
+        closesocket (listen_s);
+        sockets_pair[0] = server_s;
+        sockets_pair[1] = client_s;
+        return ! 0;
+      }
+      closesocket (server_s);
+      closesocket (client_s);
     }
+    closesocket (listen_s);
+  }
 
   sockets_pair[0] = INVALID_SOCKET;
   sockets_pair[1] = INVALID_SOCKET;
-  WSASetLastError(WSAECONNREFUSED);
+  WSASetLastError (WSAECONNREFUSED);
 
   return 0;
 }
@@ -383,9 +384,9 @@ MHD_add_to_fd_set_ (MHD_socket fd,
                                          set,
                                          fd_setsize))
     return 0;
-  MHD_SCKT_ADD_FD_TO_FDSET_SETSIZE_(fd,
-                                    set,
-                                    fd_setsize);
+  MHD_SCKT_ADD_FD_TO_FDSET_SETSIZE_ (fd,
+                                     set,
+                                     fd_setsize);
   if ( (NULL != max_fd) &&
        ( (fd > *max_fd) ||
          (MHD_INVALID_SOCKET == *max_fd) ) )
@@ -424,7 +425,7 @@ MHD_socket_nonblocking_ (MHD_socket sock)
                         &flags))
     return 0;
 #endif /* MHD_WINSOCK_SOCKETS */
-  return !0;
+  return ! 0;
 }
 
 
@@ -452,12 +453,88 @@ MHD_socket_noninheritable_ (MHD_socket sock)
                     flags | FD_CLOEXEC)) )
     return 0;
 #elif defined(MHD_WINSOCK_SOCKETS)
-  if (! SetHandleInformation ((HANDLE)sock,
+  if (! SetHandleInformation ((HANDLE) sock,
                               HANDLE_FLAG_INHERIT,
                               0))
     return 0;
 #endif /* MHD_WINSOCK_SOCKETS */
-  return !0;
+  return ! 0;
+}
+
+
+/**
+ * Disable Nagle's algorithm on @a sock.  This is what we do by default for
+ * all TCP sockets in MHD, unless the platform does not support the MSG_MORE
+ * or MSG_CORK or MSG_NOPUSH options.
+ *
+ * @param sock socket to manipulate
+ * @param on value to use
+ * @return 0 on success
+ */
+int
+MHD_socket_set_nodelay_ (MHD_socket sock,
+                         bool on)
+{
+#ifdef TCP_NODELAY
+  {
+    const MHD_SCKT_OPT_BOOL_ off_val = 0;
+    const MHD_SCKT_OPT_BOOL_ on_val = 1;
+    /* Disable Nagle's algorithm for normal buffering */
+    return setsockopt (sock,
+                       IPPROTO_TCP,
+                       TCP_NODELAY,
+                       (const void *) (on) ? &on_val : &off_val,
+                       sizeof (on_val));
+  }
+#else
+  (void) sock;
+  return 0;
+#endif /* TCP_NODELAY */
+}
+
+
+/**
+ * Enable/disable the cork option.
+ *
+ * @param sock socket to manipulate
+ * @param on set to true to enable CORK, false to disable
+ * @return non-zero if succeeded, zero otherwise
+ */
+int
+MHD_socket_cork_ (MHD_socket sock,
+                  bool on)
+{
+#if defined(MHD_TCP_CORK_NOPUSH)
+  const MHD_SCKT_OPT_BOOL_ off_val = 0;
+  const MHD_SCKT_OPT_BOOL_ on_val = 1;
+
+  /* Disable extra buffering */
+  if (0 != setsockopt (sock,
+                       IPPROTO_TCP,
+                       MHD_TCP_CORK_NOPUSH,
+                       (const void *) (on ? &on_val : &off_val),
+                       sizeof (off_val)))
+    return 0; /* failed */
+#if defined(__FreeBSD__) &&  __FreeBSD__ + 0 >= 9
+  /* FreeBSD do not need zero-send for flushing starting from version 9 */
+  return 1;
+#elif defined(TCP_NOPUSH) && ! defined(TCP_CORK)
+  {
+    const int dummy = 0;
+    /* Force flush data with zero send otherwise Darwin and some BSD systems
+       will add 5 seconds delay. Not required with TCP_CORK as switching off
+       TCP_CORK always flushes socket buffer. */
+    if (0 > send (sock,
+                  &dummy,
+                  0))
+      return 0; /* even force flush failed!? */
+    return 1; /* success */
+  }
+#endif
+#else
+  /* do not have MHD_TCP_CORK_NOPUSH at all */
+  return 0;
+#endif
 }
 
 
@@ -470,29 +547,19 @@ MHD_socket_noninheritable_ (MHD_socket sock)
 int
 MHD_socket_buffering_reset_ (MHD_socket sock)
 {
-  int res = !0;
-#if defined(TCP_NODELAY) || defined(MHD_TCP_CORK_NOPUSH)
-  const MHD_SCKT_OPT_BOOL_ off_val = 0;
 #if defined(MHD_TCP_CORK_NOPUSH)
+  int res = ! MHD_socket_set_nodelay_ (sock,
+                                       true);
   /* Disable extra buffering */
-  res = (0 == setsockopt (sock,
-                          IPPROTO_TCP,
-                          MHD_TCP_CORK_NOPUSH,
-                          (const void *) &off_val,
-                          sizeof (off_val))) && res;
+  return MHD_socket_cork_ (sock,
+                           false) && res;
+#elif defined(HAVE_MSG_MORE)
+  return ! MHD_socket_set_nodelay_ (sock,
+                                    true);
+#else
+  return ! MHD_socket_set_nodelay_ (sock,
+                                    false);
 #endif /* MHD_TCP_CORK_NOPUSH */
-#if defined(TCP_NODELAY)
-  /* Enable Nagle's algorithm for normal buffering */
-  res = (0 == setsockopt (sock,
-                          IPPROTO_TCP,
-                          TCP_NODELAY,
-                          (const void *) &off_val,
-                          sizeof (off_val))) && res;
-#endif /* TCP_NODELAY */
-#else  /* !TCP_NODELAY && !MHD_TCP_CORK_NOPUSH */
-  (void) sock;
-#endif /* !TCP_NODELAY && !MHD_TCP_CORK_NOPUSH */
-  return res;
 }
 
 
@@ -511,7 +578,8 @@ MHD_socket_create_listen_ (int pf)
   int nosigpipe_set;
 #endif /* SOCK_NOSIGPIPE ||  MHD_socket_nosignal_ */
 
-#if defined(MHD_POSIX_SOCKETS) && ( defined(SOCK_CLOEXEC) || defined(SOCK_NOSIGPIPE) )
+#if defined(MHD_POSIX_SOCKETS) && (defined(SOCK_CLOEXEC) || \
+  defined(SOCK_NOSIGPIPE) )
   fd = socket (pf,
                SOCK_STREAM | SOCK_CLOEXEC | MAYBE_SOCK_NOSIGPIPE,
                0);
@@ -526,36 +594,36 @@ MHD_socket_create_listen_ (int pf)
                    NULL,
                    0,
                    WSA_FLAG_OVERLAPPED | WSA_FLAG_NO_HANDLE_INHERIT);
-  cloexec_set = !0;
+  cloexec_set = ! 0;
 #else  /* !SOCK_CLOEXEC */
   fd = MHD_INVALID_SOCKET;
 #endif /* !SOCK_CLOEXEC */
   if (MHD_INVALID_SOCKET == fd)
-    {
-      fd = socket (pf,
-                   SOCK_STREAM,
-                   0);
-      cloexec_set = 0;
-    }
+  {
+    fd = socket (pf,
+                 SOCK_STREAM,
+                 0);
+    cloexec_set = 0;
+  }
   if (MHD_INVALID_SOCKET == fd)
     return MHD_INVALID_SOCKET;
 
 #if defined(SOCK_NOSIGPIPE) || defined(MHD_socket_nosignal_)
   if ( ( (! nosigpipe_set)
 #ifdef MHD_socket_nosignal_
-         || (! MHD_socket_nosignal_(fd))
+         || (! MHD_socket_nosignal_ (fd))
 #endif /* MHD_socket_nosignal_ */
-       ) && (0 == MAYBE_MSG_NOSIGNAL) )
-    {
-      /* SIGPIPE disable is possible on this platform
-       * (so application expect that it will be disabled),
-       * but failed to be disabled here and it is not
-       * possible to disable SIGPIPE by MSG_NOSIGNAL. */
-      const int err = MHD_socket_get_error_ ();
-      (void) MHD_socket_close_ (fd);
-      MHD_socket_fset_error_ (err);
-      return MHD_INVALID_SOCKET;
-    }
+         ) && (0 == MAYBE_MSG_NOSIGNAL) )
+  {
+    /* SIGPIPE disable is possible on this platform
+     * (so application expect that it will be disabled),
+     * but failed to be disabled here and it is not
+     * possible to disable SIGPIPE by MSG_NOSIGNAL. */
+    const int err = MHD_socket_get_error_ ();
+    (void) MHD_socket_close_ (fd);
+    MHD_socket_fset_error_ (err);
+    return MHD_INVALID_SOCKET;
+  }
 #endif /* SOCK_NOSIGPIPE ||  MHD_socket_nosignal_ */
   if (! cloexec_set)
     (void) MHD_socket_noninheritable_ (fd);
