@@ -38,10 +38,10 @@
 #endif /* MHD_HTTPS_REQUIRE_GRYPT */
 #include "tls_test_common.h"
 
-#if defined(CPU_COUNT) && (CPU_COUNT+0) < 4
+#if defined(CPU_COUNT) && (CPU_COUNT + 0) < 4
 #undef CPU_COUNT
 #endif
-#if !defined(CPU_COUNT)
+#if ! defined(CPU_COUNT)
 #define CPU_COUNT 4
 #endif
 
@@ -83,8 +83,8 @@ test_single_client (void *cls, int port, const char *cipher_suite,
 {
   void *client_thread_ret;
   struct https_test_data client_args =
-    { NULL, port, cipher_suite, curl_proto_version };
-  (void)cls;    /* Unused. Silent compiler warning. */
+  { NULL, port, cipher_suite, curl_proto_version };
+  (void) cls;    /* Unused. Silent compiler warning. */
 
   client_thread_ret = https_transfer_thread_adapter (&client_args);
   if (client_thread_ret != NULL)
@@ -109,27 +109,27 @@ test_parallel_clients (void *cls, int port, const char *cipher_suite,
   void *client_thread_ret;
   pthread_t client_arr[client_count];
   struct https_test_data client_args =
-    { NULL, port, cipher_suite, curl_proto_version };
-  (void)cls;    /* Unused. Silent compiler warning. */
+  { NULL, port, cipher_suite, curl_proto_version };
+  (void) cls;    /* Unused. Silent compiler warning. */
 
   for (i = 0; i < client_count; ++i)
+  {
+    if (pthread_create (&client_arr[i], NULL,
+                        &https_transfer_thread_adapter, &client_args) != 0)
     {
-      if (pthread_create (&client_arr[i], NULL,
-                          &https_transfer_thread_adapter, &client_args) != 0)
-        {
-          fprintf (stderr, "Error: failed to spawn test client threads.\n");
+      fprintf (stderr, "Error: failed to spawn test client threads.\n");
 
-          return -1;
-        }
+      return -1;
     }
+  }
 
   /* check all client requests fulfilled correctly */
   for (i = 0; i < client_count; ++i)
-    {
-      if ((pthread_join (client_arr[i], &client_thread_ret) != 0) ||
-          (client_thread_ret != NULL))
-        return -1;
-    }
+  {
+    if ((pthread_join (client_arr[i], &client_thread_ret) != 0) ||
+        (client_thread_ret != NULL))
+      return -1;
+  }
 
   return 0;
 }
@@ -141,7 +141,7 @@ main (int argc, char *const *argv)
   unsigned int errorCount = 0;
   const char *ssl_version;
   int port;
-  (void)argc;   /* Unused. Silent compiler warning. */
+  (void) argc;   /* Unused. Silent compiler warning. */
 
   if (MHD_NO != MHD_is_feature_supported (MHD_FEATURE_AUTODETECT_BIND_PORT))
     port = 0;
@@ -157,32 +157,33 @@ main (int argc, char *const *argv)
 #endif
 #endif /* MHD_HTTPS_REQUIRE_GRYPT */
   srand (iseed);
-  if (!testsuite_curl_global_init ())
+  if (! testsuite_curl_global_init ())
     return 99;
   ssl_version = curl_version_info (CURLVERSION_NOW)->ssl_version;
   if (NULL == ssl_version)
-    {
-      fprintf (stderr, "Curl does not support SSL.  Cannot run the test.\n");
-      curl_global_cleanup ();
-      return 77;
-    }
+  {
+    fprintf (stderr, "Curl does not support SSL.  Cannot run the test.\n");
+    curl_global_cleanup ();
+    return 77;
+  }
   if (0 != strncmp (ssl_version, "GnuTLS", 6))
-    {
-      fprintf (stderr, "This test can be run only with libcurl-gnutls.\n");
-      curl_global_cleanup ();
-      return 77;
-    }
+  {
+    fprintf (stderr, "This test can be run only with libcurl-gnutls.\n");
+    curl_global_cleanup ();
+    return 77;
+  }
 
   char *aes256_sha = "AES256-SHA";
-  if (curl_uses_nss_ssl() == 0)
-    {
-      aes256_sha = "rsa_aes_256_sha";
-    }
+  if (curl_uses_nss_ssl () == 0)
+  {
+    aes256_sha = "rsa_aes_256_sha";
+  }
 
   errorCount +=
     test_wrap ("multi threaded daemon, single client", &test_single_client,
                NULL, port,
-               MHD_USE_TLS | MHD_USE_ERROR_LOG | MHD_USE_THREAD_PER_CONNECTION | MHD_USE_INTERNAL_POLLING_THREAD,
+               MHD_USE_TLS | MHD_USE_ERROR_LOG | MHD_USE_THREAD_PER_CONNECTION
+               | MHD_USE_INTERNAL_POLLING_THREAD,
                aes256_sha, CURL_SSLVERSION_TLSv1, MHD_OPTION_HTTPS_MEM_KEY,
                srv_key_pem, MHD_OPTION_HTTPS_MEM_CERT,
                srv_self_signed_cert_pem, MHD_OPTION_END);
@@ -190,7 +191,8 @@ main (int argc, char *const *argv)
   errorCount +=
     test_wrap ("multi threaded daemon, parallel client",
                &test_parallel_clients, NULL, port,
-               MHD_USE_TLS | MHD_USE_ERROR_LOG | MHD_USE_THREAD_PER_CONNECTION | MHD_USE_INTERNAL_POLLING_THREAD,
+               MHD_USE_TLS | MHD_USE_ERROR_LOG | MHD_USE_THREAD_PER_CONNECTION
+               | MHD_USE_INTERNAL_POLLING_THREAD,
                aes256_sha, CURL_SSLVERSION_TLSv1, MHD_OPTION_HTTPS_MEM_KEY,
                srv_key_pem, MHD_OPTION_HTTPS_MEM_CERT,
                srv_self_signed_cert_pem, MHD_OPTION_END);
