@@ -41,38 +41,41 @@ extern const char srv_signed_key_pem[];
 
 /* perform a HTTP GET request via SSL/TLS */
 static int
-test_secure_get (void * cls, char *cipher_suite, int proto_version)
+test_secure_get (void *cls, char *cipher_suite, int proto_version)
 {
   int ret;
   struct MHD_Daemon *d;
   int port;
-  (void)cls;    /* Unused. Silent compiler warning. */
+  (void) cls;    /* Unused. Silent compiler warning. */
 
   if (MHD_NO != MHD_is_feature_supported (MHD_FEATURE_AUTODETECT_BIND_PORT))
     port = 0;
   else
     port = 3070;
 
-  d = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION | MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_TLS |
-                        MHD_USE_ERROR_LOG, port,
+  d = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION
+                        | MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_TLS
+                        | MHD_USE_ERROR_LOG, port,
                         NULL, NULL, &http_ahc, NULL,
                         MHD_OPTION_HTTPS_MEM_KEY, srv_signed_key_pem,
                         MHD_OPTION_HTTPS_MEM_CERT, srv_signed_cert_pem,
                         MHD_OPTION_END);
 
   if (d == NULL)
-    {
-      fprintf (stderr, MHD_E_SERVER_INIT);
-      return -1;
-    }
+  {
+    fprintf (stderr, MHD_E_SERVER_INIT);
+    return -1;
+  }
   if (0 == port)
+  {
+    const union MHD_DaemonInfo *dinfo;
+    dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
+    if ((NULL == dinfo) ||(0 == dinfo->port) )
     {
-      const union MHD_DaemonInfo *dinfo;
-      dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
-      if (NULL == dinfo || 0 == dinfo->port)
-        { MHD_stop_daemon (d); return -1; }
-      port = (int)dinfo->port;
+      MHD_stop_daemon (d); return -1;
     }
+    port = (int) dinfo->port;
+  }
 
   ret = test_daemon_get (NULL, cipher_suite, proto_version, port, 0);
 
@@ -87,8 +90,8 @@ main (int argc, char *const *argv)
   unsigned int errorCount = 0;
   char *aes256_sha = "AES256-SHA";
   FILE *crt;
-  (void)argc;
-  (void)argv;       /* Unused. Silent compiler warning. */
+  (void) argc;
+  (void) argv;       /* Unused. Silent compiler warning. */
 
 #ifdef MHD_HTTPS_REQUIRE_GRYPT
   gcry_control (GCRYCTL_ENABLE_QUICK_RANDOM, 0);
@@ -96,26 +99,26 @@ main (int argc, char *const *argv)
   gcry_control (GCRYCTL_INITIALIZATION_FINISHED, 0);
 #endif
 #endif /* MHD_HTTPS_REQUIRE_GRYPT */
-  if (!testsuite_curl_global_init ())
+  if (! testsuite_curl_global_init ())
     return 99;
   if (NULL == curl_version_info (CURLVERSION_NOW)->ssl_version)
-    {
-      fprintf (stderr, "Curl does not support SSL.  Cannot run the test.\n");
-      curl_global_cleanup ();
-      return 77;
-    }
+  {
+    fprintf (stderr, "Curl does not support SSL.  Cannot run the test.\n");
+    curl_global_cleanup ();
+    return 77;
+  }
 
   if (NULL == (crt = setup_ca_cert ()))
-    {
-      fprintf (stderr, MHD_E_TEST_FILE_CREAT);
-      curl_global_cleanup ();
-      return 99;
-    }
+  {
+    fprintf (stderr, MHD_E_TEST_FILE_CREAT);
+    curl_global_cleanup ();
+    return 99;
+  }
   fclose (crt);
-  if (curl_uses_nss_ssl() == 0)
-    {
-      aes256_sha = "rsa_aes_256_sha";
-    }
+  if (curl_uses_nss_ssl () == 0)
+  {
+    aes256_sha = "rsa_aes_256_sha";
+  }
 
   errorCount +=
     test_secure_get (NULL, aes256_sha, CURL_SSLVERSION_TLSv1);
@@ -125,7 +128,7 @@ main (int argc, char *const *argv)
   curl_global_cleanup ();
   if (0 != remove (ca_cert_file_name))
     fprintf (stderr,
-	     "Failed to remove `%s'\n",
-	     ca_cert_file_name);
+             "Failed to remove `%s'\n",
+             ca_cert_file_name);
   return errorCount != 0 ? 1 : 0;
 }
