@@ -33,26 +33,26 @@ setup_ca_cert ()
   FILE *cert_fd;
 
   if (NULL == (cert_fd = fopen (ca_cert_file_name, "wb+")))
-    {
-      fprintf (stderr, "Error: failed to open `%s': %s\n",
-               ca_cert_file_name, strerror (errno));
-      return NULL;
-    }
+  {
+    fprintf (stderr, "Error: failed to open `%s': %s\n",
+             ca_cert_file_name, strerror (errno));
+    return NULL;
+  }
   if (fwrite (ca_cert_pem, sizeof (char), strlen (ca_cert_pem) + 1, cert_fd)
       != strlen (ca_cert_pem) + 1)
-    {
-      fprintf (stderr, "Error: failed to write `%s. %s'\n",
-               ca_cert_file_name, strerror (errno));
-      fclose (cert_fd);
-      return NULL;
-    }
+  {
+    fprintf (stderr, "Error: failed to write `%s. %s'\n",
+             ca_cert_file_name, strerror (errno));
+    fclose (cert_fd);
+    return NULL;
+  }
   if (fflush (cert_fd))
-    {
-      fprintf (stderr, "Error: failed to flush ca cert file stream. %s\n",
-               strerror (errno));
-      fclose (cert_fd);
-      return NULL;
-    }
+  {
+    fprintf (stderr, "Error: failed to flush ca cert file stream. %s\n",
+             strerror (errno));
+    fclose (cert_fd);
+    return NULL;
+  }
   return cert_fd;
 }
 
@@ -62,23 +62,23 @@ setup_ca_cert ()
  */
 int
 test_daemon_get (void *cls,
-		 const char *cipher_suite, int proto_version,
-		 int port,
-		 int ver_peer)
+                 const char *cipher_suite, int proto_version,
+                 int port,
+                 int ver_peer)
 {
   CURL *c;
   struct CBC cbc;
   CURLcode errornum;
   char url[255];
   size_t len;
-  (void)cls;    /* Unused. Silent compiler warning. */
+  (void) cls;    /* Unused. Silent compiler warning. */
 
   len = strlen (test_data);
   if (NULL == (cbc.buf = malloc (sizeof (char) * len)))
-    {
-      fprintf (stderr, MHD_E_MEM);
-      return -1;
-    }
+  {
+    fprintf (stderr, MHD_E_MEM);
+    return -1;
+  }
   cbc.size = len;
   cbc.pos = 0;
 
@@ -115,22 +115,22 @@ test_daemon_get (void *cls,
      crashes on my system! */
   curl_easy_setopt (c, CURLOPT_NOSIGNAL, 1L);
   if (CURLE_OK != (errornum = curl_easy_perform (c)))
-    {
-      fprintf (stderr, "curl_easy_perform failed: `%s'\n",
-               curl_easy_strerror (errornum));
-      curl_easy_cleanup (c);
-      free (cbc.buf);
-      return errornum;
-    }
+  {
+    fprintf (stderr, "curl_easy_perform failed: `%s'\n",
+             curl_easy_strerror (errornum));
+    curl_easy_cleanup (c);
+    free (cbc.buf);
+    return errornum;
+  }
 
   curl_easy_cleanup (c);
 
   if (memcmp (cbc.buf, test_data, len) != 0)
-    {
-      fprintf (stderr, "Error: local file & received file differ.\n");
-      free (cbc.buf);
-      return -1;
-    }
+  {
+    fprintf (stderr, "Error: local file & received file differ.\n");
+    free (cbc.buf);
+    return -1;
+  }
 
   free (cbc.buf);
   return 0;
@@ -141,7 +141,9 @@ void
 print_test_result (int test_outcome, char *test_name)
 {
   if (test_outcome != 0)
-    fprintf (stderr, "running test: %s [fail: %u]\n", test_name, (unsigned int)test_outcome);
+    fprintf (stderr, "running test: %s [fail: %u]\n", test_name, (unsigned
+                                                                  int)
+             test_outcome);
 #if 0
   else
     fprintf (stdout, "running test: %s [pass]\n", test_name);
@@ -171,21 +173,21 @@ http_ahc (void *cls, struct MHD_Connection *connection,
   static int aptr;
   struct MHD_Response *response;
   int ret;
-  (void)cls;(void)url;(void)version;            /* Unused. Silent compiler warning. */
-  (void)upload_data;(void)upload_data_size;     /* Unused. Silent compiler warning. */
+  (void) cls; (void) url; (void) version;            /* Unused. Silent compiler warning. */
+  (void) upload_data; (void) upload_data_size;     /* Unused. Silent compiler warning. */
 
   if (0 != strcmp (method, MHD_HTTP_METHOD_GET))
     return MHD_NO;              /* unexpected method */
   if (&aptr != *ptr)
-    {
-      /* do never respond on first call */
-      *ptr = &aptr;
-      return MHD_YES;
-    }
+  {
+    /* do never respond on first call */
+    *ptr = &aptr;
+    return MHD_YES;
+  }
   *ptr = NULL;                  /* reset when done */
   response = MHD_create_response_from_buffer (strlen (test_data),
-					      (void *) test_data,
-					      MHD_RESPMEM_PERSISTENT);
+                                              (void *) test_data,
+                                              MHD_RESPMEM_PERSISTENT);
   ret = MHD_queue_response (connection, MHD_HTTP_OK, response);
   MHD_destroy_response (response);
   return ret;
@@ -198,9 +200,9 @@ http_dummy_ahc (void *cls, struct MHD_Connection *connection,
                 const char *upload_data, size_t *upload_data_size,
                 void **ptr)
 {
-  (void)cls;(void)connection;(void)url;(void)method;(void)version;      /* Unused. Silent compiler warning. */
-  (void)upload_data;(void)upload_data_size;(void)ptr;                   /* Unused. Silent compiler warning. */
- return 0;
+  (void) cls; (void) connection; (void) url; (void) method; (void) version;      /* Unused. Silent compiler warning. */
+  (void) upload_data; (void) upload_data_size; (void) ptr;                   /* Unused. Silent compiler warning. */
+  return 0;
 }
 
 /**
@@ -213,7 +215,7 @@ http_dummy_ahc (void *cls, struct MHD_Connection *connection,
  */
 /* TODO have test wrap consider a NULL cbc */
 int
-send_curl_req (char *url, struct CBC * cbc, const char *cipher_suite,
+send_curl_req (char *url, struct CBC *cbc, const char *cipher_suite,
                int proto_version)
 {
   CURL *c;
@@ -228,10 +230,10 @@ send_curl_req (char *url, struct CBC * cbc, const char *cipher_suite,
   curl_easy_setopt (c, CURLOPT_CONNECTTIMEOUT, 60L);
 
   if (cbc != NULL)
-    {
-      curl_easy_setopt (c, CURLOPT_WRITEFUNCTION, &copyBuffer);
-      curl_easy_setopt (c, CURLOPT_FILE, cbc);
-    }
+  {
+    curl_easy_setopt (c, CURLOPT_WRITEFUNCTION, &copyBuffer);
+    curl_easy_setopt (c, CURLOPT_FILE, cbc);
+  }
 
   /* TLS options */
   curl_easy_setopt (c, CURLOPT_SSLVERSION, proto_version);
@@ -248,12 +250,12 @@ send_curl_req (char *url, struct CBC * cbc, const char *cipher_suite,
      crashes on my system! */
   curl_easy_setopt (c, CURLOPT_NOSIGNAL, 1L);
   if (CURLE_OK != (errornum = curl_easy_perform (c)))
-    {
-      fprintf (stderr, "curl_easy_perform failed: `%s'\n",
-               curl_easy_strerror (errornum));
-      curl_easy_cleanup (c);
-      return errornum;
-    }
+  {
+    fprintf (stderr, "curl_easy_perform failed: `%s'\n",
+             curl_easy_strerror (errornum));
+    curl_easy_cleanup (c);
+    return errornum;
+  }
   curl_easy_cleanup (c);
 
   return CURLE_OK;
@@ -286,27 +288,27 @@ gen_test_file_url (char *url,
   size_t i;
 #endif /* ! WINDOWS */
   if (NULL == (doc_path = malloc (doc_path_len)))
-    {
-      fprintf (stderr, MHD_E_MEM);
-      return -1;
-    }
+  {
+    fprintf (stderr, MHD_E_MEM);
+    return -1;
+  }
   if (NULL == getcwd (doc_path, doc_path_len))
-    {
-      fprintf (stderr,
-               "Error: failed to get working directory. %s\n",
-               strerror (errno));
-      free (doc_path);
-      return -1;
-    }
+  {
+    fprintf (stderr,
+             "Error: failed to get working directory. %s\n",
+             strerror (errno));
+    free (doc_path);
+    return -1;
+  }
 #ifdef WINDOWS
   for (i = 0; i < doc_path_len; i++)
   {
     if (doc_path[i] == 0)
       break;
     if (doc_path[i] == '\\')
-      {
-        doc_path[i] = '/';
-      }
+    {
+      doc_path[i] = '/';
+    }
     if (doc_path[i] != ':')
       continue;
     if (i == 0)
@@ -322,7 +324,7 @@ gen_test_file_url (char *url,
                 "https://127.0.0.1",
                 port,
                 doc_path,
-                "urlpath") >= (long long)url_len)
+                "urlpath") >= (long long) url_len)
     ret = -1;
 
   free (doc_path);
@@ -343,41 +345,41 @@ test_https_transfer (void *cls,
   int ret = 0;
   struct CBC cbc;
   char url[255];
-  (void)cls;    /* Unused. Silent compiler warning. */
+  (void) cls;    /* Unused. Silent compiler warning. */
 
   len = strlen (test_data);
   if (NULL == (cbc.buf = malloc (sizeof (char) * len)))
-    {
-      fprintf (stderr, MHD_E_MEM);
-      return -1;
-    }
+  {
+    fprintf (stderr, MHD_E_MEM);
+    return -1;
+  }
   cbc.size = len;
   cbc.pos = 0;
 
   if (gen_test_file_url (url,
                          sizeof (url),
                          port))
-    {
-      ret = -1;
-      goto cleanup;
-    }
+  {
+    ret = -1;
+    goto cleanup;
+  }
 
   if (CURLE_OK !=
       send_curl_req (url, &cbc, cipher_suite, proto_version))
-    {
-      ret = -1;
-      goto cleanup;
-    }
+  {
+    ret = -1;
+    goto cleanup;
+  }
 
   /* compare test file & daemon responce */
   if ( (len != strlen (test_data)) ||
        (memcmp (cbc.buf,
-		test_data,
-		len) != 0) )
-    {
-      fprintf (stderr, "Error: local file & received file differ.\n");
-      ret = -1;
-    }
+                test_data,
+                len) != 0) )
+  {
+    fprintf (stderr, "Error: local file & received file differ.\n");
+    ret = -1;
+  }
 cleanup:
   free (cbc.buf);
   return ret;
@@ -392,28 +394,29 @@ cleanup:
  * @return port number on success or zero on failure
  */
 int
-setup_testcase (struct MHD_Daemon **d, int port, int daemon_flags, va_list arg_list)
+setup_testcase (struct MHD_Daemon **d, int port, int daemon_flags, va_list
+                arg_list)
 {
   *d = MHD_start_daemon_va (daemon_flags, port,
                             NULL, NULL, &http_ahc, NULL, arg_list);
 
   if (*d == NULL)
-    {
-      fprintf (stderr, MHD_E_SERVER_INIT);
-      return 0;
-    }
+  {
+    fprintf (stderr, MHD_E_SERVER_INIT);
+    return 0;
+  }
 
   if (0 == port)
+  {
+    const union MHD_DaemonInfo *dinfo;
+    dinfo = MHD_get_daemon_info (*d, MHD_DAEMON_INFO_BIND_PORT);
+    if ((NULL == dinfo) ||(0 == dinfo->port) )
     {
-      const union MHD_DaemonInfo *dinfo;
-      dinfo = MHD_get_daemon_info (*d, MHD_DAEMON_INFO_BIND_PORT);
-      if (NULL == dinfo || 0 == dinfo->port)
-        {
-          MHD_stop_daemon (*d);
-          return 0;
-        }
-      port = (int)dinfo->port;
+      MHD_stop_daemon (*d);
+      return 0;
     }
+    port = (int) dinfo->port;
+  }
 
   return port;
 }
@@ -425,10 +428,10 @@ teardown_testcase (struct MHD_Daemon *d)
 }
 
 int
-setup_session (gnutls_session_t * session,
-               gnutls_datum_t * key,
-               gnutls_datum_t * cert,
-	       gnutls_certificate_credentials_t * xcred)
+setup_session (gnutls_session_t *session,
+               gnutls_datum_t *key,
+               gnutls_datum_t *cert,
+               gnutls_certificate_credentials_t *xcred)
 {
   int ret;
   const char *err_pos;
@@ -437,42 +440,42 @@ setup_session (gnutls_session_t * session,
   key->size = strlen (srv_key_pem) + 1;
   key->data = malloc (key->size);
   if (NULL == key->data)
-     {
-       gnutls_certificate_free_credentials (*xcred);
-	return -1;
-     }
+  {
+    gnutls_certificate_free_credentials (*xcred);
+    return -1;
+  }
   memcpy (key->data, srv_key_pem, key->size);
   cert->size = strlen (srv_self_signed_cert_pem) + 1;
   cert->data = malloc (cert->size);
   if (NULL == cert->data)
-    {
-        gnutls_certificate_free_credentials (*xcred);
-	free (key->data);
-	return -1;
-    }
+  {
+    gnutls_certificate_free_credentials (*xcred);
+    free (key->data);
+    return -1;
+  }
   memcpy (cert->data, srv_self_signed_cert_pem, cert->size);
   gnutls_certificate_set_x509_key_mem (*xcred, cert, key,
-				       GNUTLS_X509_FMT_PEM);
+                                       GNUTLS_X509_FMT_PEM);
   gnutls_init (session, GNUTLS_CLIENT);
   ret = gnutls_priority_set_direct (*session,
-				    "NORMAL", &err_pos);
+                                    "NORMAL", &err_pos);
   if (ret < 0)
-    {
-       gnutls_deinit (*session);
-       gnutls_certificate_free_credentials (*xcred);
-       free (key->data);
-       return -1;
-    }
+  {
+    gnutls_deinit (*session);
+    gnutls_certificate_free_credentials (*xcred);
+    free (key->data);
+    return -1;
+  }
   gnutls_credentials_set (*session,
-			  GNUTLS_CRD_CERTIFICATE,
-			  *xcred);
+                          GNUTLS_CRD_CERTIFICATE,
+                          *xcred);
   return 0;
 }
 
 int
 teardown_session (gnutls_session_t session,
-                  gnutls_datum_t * key,
-                  gnutls_datum_t * cert,
+                  gnutls_datum_t *key,
+                  gnutls_datum_t *cert,
                   gnutls_certificate_credentials_t xcred)
 {
   free (key->data);
@@ -489,37 +492,37 @@ teardown_session (gnutls_session_t session,
 /* TODO test_wrap: change sig to (setup_func, test, va_list test_arg) */
 int
 test_wrap (const char *test_name, int
-           (*test_function) (void * cls, int port, const char *cipher_suite,
-                             int proto_version), void * cls,
+           (*test_function)(void *cls, int port, const char *cipher_suite,
+                            int proto_version), void *cls,
            int port,
            int daemon_flags, const char *cipher_suite, int proto_version, ...)
 {
   int ret;
   va_list arg_list;
   struct MHD_Daemon *d;
-  (void)cls;    /* Unused. Silent compiler warning. */
+  (void) cls;    /* Unused. Silent compiler warning. */
 
   va_start (arg_list, proto_version);
   port = setup_testcase (&d, port, daemon_flags, arg_list);
   if (0 == port)
-    {
-      va_end (arg_list);
-      fprintf (stderr, "Failed to setup testcase %s\n", test_name);
-      return -1;
-    }
+  {
+    va_end (arg_list);
+    fprintf (stderr, "Failed to setup testcase %s\n", test_name);
+    return -1;
+  }
 #if 0
   fprintf (stdout, "running test: %s ", test_name);
 #endif
   ret = test_function (NULL, port, cipher_suite, proto_version);
 #if 0
   if (ret == 0)
-    {
-      fprintf (stdout, "[pass]\n");
-    }
+  {
+    fprintf (stdout, "[pass]\n");
+  }
   else
-    {
-      fprintf (stdout, "[fail]\n");
-    }
+  {
+    fprintf (stdout, "[fail]\n");
+  }
 #endif
   teardown_testcase (d);
   va_end (arg_list);
@@ -532,17 +535,19 @@ testsuite_curl_global_init (void)
 {
   CURLcode res;
 #if LIBCURL_VERSION_NUM >= 0x073800
-  if (CURLSSLSET_OK != curl_global_sslset(CURLSSLBACKEND_GNUTLS, NULL, NULL))
-    {
-      if (CURLSSLSET_TOO_LATE == curl_global_sslset(CURLSSLBACKEND_OPENSSL, NULL, NULL))
-        fprintf (stderr, "WARNING: libcurl was already initialised.\n");
-    }
+  if (CURLSSLSET_OK != curl_global_sslset (CURLSSLBACKEND_GNUTLS, NULL, NULL))
+  {
+    if (CURLSSLSET_TOO_LATE == curl_global_sslset (CURLSSLBACKEND_OPENSSL, NULL,
+                                                   NULL))
+      fprintf (stderr, "WARNING: libcurl was already initialised.\n");
+  }
 #endif /* LIBCURL_VERSION_NUM >= 0x07380 */
   res = curl_global_init (CURL_GLOBAL_ALL);
   if (CURLE_OK != res)
-    {
-      fprintf (stderr, "libcurl initialisation error: %s\n", curl_easy_strerror(res));
-      return 0;
-    }
+  {
+    fprintf (stderr, "libcurl initialisation error: %s\n", curl_easy_strerror (
+               res));
+    return 0;
+  }
   return 1;
 }
